"""
Shortly - A simple URL shortening library.

@author:   RknDeveloper
@contact:  https://t.me/RknDeveloperr
@license:  MIT License, see LICENSE file

Copyright (c) 2025-present RknDeveloper
"""


__version__ = "0.0.6"
__author__ = "RknDeveloper"
__license__ = "MIT License "
__copyright__ = "Copyright (C) 2025-present RknDeveloper <https://github.com/RknDeveloper>"

from .shortly import Shortly
from .exceptions import ShortlyError
